==> cucumber-reports-3.10.0-sources.jar: net/masterthought/jenkins/Messages.java <==
// CHECKSTYLE:OFF

package net.masterthought.jenkins;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code SidePanel.DisplayName}: {@code Cucumber reports}.
     * 
     * @return
     *     {@code Cucumber reports}
     */
    public static String SidePanel_DisplayName() {
        return holder.format("SidePanel.DisplayName");
    }

    /**
     * Key {@code SidePanel.DisplayName}: {@code Cucumber reports}.
     * 
     * @return
     *     {@code Cucumber reports}
     */
    public static Localizable _SidePanel_DisplayName() {
        return new Localizable(holder, "SidePanel.DisplayName");
    }

    /**
     * Key {@code SortingMethod.NATURAL}: {@code By test execution

     * (natural)}.
     * 
     * @return
     *     {@code By test execution (natural)}
     */
    public static String SortingMethod_NATURAL() {
        return holder.format("SortingMethod.NATURAL");
    }

    /**
     * Key {@code SortingMethod.NATURAL}: {@code By test execution

     * (natural)}.
     * 
     * @return
     *     {@code By test execution (natural)}
     */
    public static Localizable _SortingMethod_NATURAL() {
        return new Localizable(holder, "SortingMethod.NATURAL");
    }

    /**
     * Key {@code Configuration.notValidNumber}: {@code Provide integer

     * value}.
     * 
     * @return
     *     {@code Provide integer value}
     */
    public static String Configuration_notValidNumber() {
        return holder.format("Configuration.notValidNumber");
    }

    /**
     * Key {@code Configuration.notValidNumber}: {@code Provide integer

     * value}.
     * 
     * @return
     *     {@code Provide integer value}
     */
    public static Localizable _Configuration_notValidNumber() {
        return new Localizable(holder, "Configuration.notValidNumber");
    }

    /**
     * Key {@code BuildStatus.UNSTABLE}: {@code Unstable}.
     * 
     * @return
     *     {@code Unstable}
     */
    public static String BuildStatus_UNSTABLE() {
        return holder.format("BuildStatus.UNSTABLE");
    }

    /**
     * Key {@code BuildStatus.UNSTABLE}: {@code Unstable}.
     * 
     * @return
     *     {@code Unstable}
     */
    public static Localizable _BuildStatus_UNSTABLE() {
        return new Localizable(holder, "BuildStatus.UNSTABLE");
    }

    /**
     * Key {@code BuildStatus.FAILURE}: {@code Failure}.
     * 
     * @return
     *     {@code Failure}
     */
    public static String BuildStatus_FAILURE() {
        return holder.format("BuildStatus.FAILURE");
    }

    /**
     * Key {@code BuildStatus.FAILURE}: {@code Failure}.
     * 
     * @return
     *     {@code Failure}
     */
    public static Localizable _BuildStatus_FAILURE() {
        return new Localizable(holder, "BuildStatus.FAILURE");
    }

    /**
     * Key {@code SortingMethod.ALPHABETICAL}: {@code By feature name

     * (alphabetical)}.
     * 
     * @return
     *     {@code By feature name (alphabetical)}
     */
    public static String SortingMethod_ALPHABETICAL() {
        return holder.format("SortingMethod.ALPHABETICAL");
    }

    /**
     * Key {@code SortingMethod.ALPHABETICAL}: {@code By feature name

     * (alphabetical)}.
     * 
     * @return
     *     {@code By feature name (alphabetical)}
     */
    public static Localizable _SortingMethod_ALPHABETICAL() {
        return new Localizable(holder, "SortingMethod.ALPHABETICAL");
    }

    /**
     * Key {@code Configuration.notValidNumberRange}: {@code Provide positive

     * value}.
     * 
     * @return
     *     {@code Provide positive value}
     */
    public static String Configuration_notValidNumberRange() {
        return holder.format("Configuration.notValidNumberRange");
    }

    /**
     * Key {@code Configuration.notValidNumberRange}: {@code Provide positive

     * value}.
     * 
     * @return
     *     {@code Provide positive value}
     */
    public static Localizable _Configuration_notValidNumberRange() {
        return new Localizable(holder, "Configuration.notValidNumberRange");
    }

    /**
     * Key {@code Plugin.DisplayName}: {@code Cucumber reports}.
     * 
     * @return
     *     {@code Cucumber reports}
     */
    public static String Plugin_DisplayName() {
        return holder.format("Plugin.DisplayName");
    }

    /**
     * Key {@code Plugin.DisplayName}: {@code Cucumber reports}.
     * 
     * @return
     *     {@code Cucumber reports}
     */
    public static Localizable _Plugin_DisplayName() {
        return new Localizable(holder, "Plugin.DisplayName");
    }

    /**
     * Key {@code BuildStatus.unchanged}: {@code Left unchanged}.
     * 
     * @return
     *     {@code Left unchanged}
     */
    public static String BuildStatus_unchanged() {
        return holder.format("BuildStatus.unchanged");
    }

    /**
     * Key {@code BuildStatus.unchanged}: {@code Left unchanged}.
     * 
     * @return
     *     {@code Left unchanged}
     */
    public static Localizable _BuildStatus_unchanged() {
        return new Localizable(holder, "BuildStatus.unchanged");
    }

}

==> cucumber-reports-4.10.0-sources.jar: net/masterthought/jenkins/Messages.java <==
// CHECKSTYLE:OFF

package net.masterthought.jenkins;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;
import org.kohsuke.accmod.Restricted;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
@Restricted(org.kohsuke.accmod.restrictions.NoExternalUse.class)
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code SidePanel.DisplayName}: {@code Cucumber reports}.
     * 
     * @return
     *     {@code Cucumber reports}
     */
    public static String SidePanel_DisplayName() {
        return holder.format("SidePanel.DisplayName");
    }

    /**
     * Key {@code SidePanel.DisplayName}: {@code Cucumber reports}.
     * 
     * @return
     *     {@code Cucumber reports}
     */
    public static Localizable _SidePanel_DisplayName() {
        return new Localizable(holder, "SidePanel.DisplayName");
    }

    /**
     * Key {@code Configuration.notValidInteger}: {@code Provide integer

     * value}.
     * 
     * @return
     *     {@code Provide integer value}
     */
    public static String Configuration_notValidInteger() {
        return holder.format("Configuration.notValidInteger");
    }

    /**
     * Key {@code Configuration.notValidInteger}: {@code Provide integer

     * value}.
     * 
     * @return
     *     {@code Provide integer value}
     */
    public static Localizable _Configuration_notValidInteger() {
        return new Localizable(holder, "Configuration.notValidInteger");
    }

    /**
     * Key {@code SortingMethod.NATURAL}: {@code By test execution

     * (natural)}.
     * 
     * @return
     *     {@code By test execution (natural)}
     */
    public static String SortingMethod_NATURAL() {
        return holder.format("SortingMethod.NATURAL");
    }

    /**
     * Key {@code SortingMethod.NATURAL}: {@code By test execution

     * (natural)}.
     * 
     * @return
     *     {@code By test execution (natural)}
     */
    public static Localizable _SortingMethod_NATURAL() {
        return new Localizable(holder, "SortingMethod.NATURAL");
    }

    /**
     * Key {@code Configuration.notValidNumber}: {@code Provide integer value

     * or -1 if this rule should not take effect for the build result}.
     * 
     * @return
     *     {@code Provide integer value or -1 if this rule should not take effect

     *     for the build result}
     */
    public static String Configuration_notValidNumber() {
        return holder.format("Configuration.notValidNumber");
    }

    /**
     * Key {@code Configuration.notValidNumber}: {@code Provide integer value

     * or -1 if this rule should not take effect for the build result}.
     * 
     * @return
     *     {@code Provide integer value or -1 if this rule should not take effect

     *     for the build result}
     */
    public static Localizable _Configuration_notValidNumber() {
        return new Localizable(holder, "Configuration.notValidNumber");
    }

    /**
     * Key {@code BuildStatus.UNSTABLE}: {@code Unstable}.
     * 
     * @return
     *     {@code Unstable}
     */
    public static String BuildStatus_UNSTABLE() {
        return holder.format("BuildStatus.UNSTABLE");
    }

    /**
     * Key {@code BuildStatus.UNSTABLE}: {@code Unstable}.
     * 
     * @return
     *     {@code Unstable}
     */
    public static Localizable _BuildStatus_UNSTABLE() {
        return new Localizable(holder, "BuildStatus.UNSTABLE");
    }

    /**
     * Key {@code Configuration.skipValidation}: {@code This rule does not

     * take effect for the build result}.
     * 
     * @return
     *     {@code This rule does not take effect for the build result}
     */
    public static String Configuration_skipValidation() {
        return holder.format("Configuration.skipValidation");
    }

    /**
     * Key {@code Configuration.skipValidation}: {@code This rule does not

     * take effect for the build result}.
     * 
     * @return
     *     {@code This rule does not take effect for the build result}
     */
    public static Localizable _Configuration_skipValidation() {
        return new Localizable(holder, "Configuration.skipValidation");
    }

    /**
     * Key {@code StopBuildOnFailedReport.FailNote}: {@code Cucumber reports

     * failed}.
     * 
     * @return
     *     {@code Cucumber reports failed}
     */
    public static String StopBuildOnFailedReport_FailNote() {
        return holder.format("StopBuildOnFailedReport.FailNote");
    }

    /**
     * Key {@code StopBuildOnFailedReport.FailNote}: {@code Cucumber reports

     * failed}.
     * 
     * @return
     *     {@code Cucumber reports failed}
     */
    public static Localizable _StopBuildOnFailedReport_FailNote() {
        return new Localizable(holder, "StopBuildOnFailedReport.FailNote");
    }

    /**
     * Key {@code Configuration.notValidPercentage}: {@code Provide

     * percentage as floating value}.
     * 
     * @return
     *     {@code Provide percentage as floating value}
     */
    public static String Configuration_notValidPercentage() {
        return holder.format("Configuration.notValidPercentage");
    }

    /**
     * Key {@code Configuration.notValidPercentage}: {@code Provide

     * percentage as floating value}.
     * 
     * @return
     *     {@code Provide percentage as floating value}
     */
    public static Localizable _Configuration_notValidPercentage() {
        return new Localizable(holder, "Configuration.notValidPercentage");
    }

    /**
     * Key {@code BuildStatus.FAILURE}: {@code Failure}.
     * 
     * @return
     *     {@code Failure}
     */
    public static String BuildStatus_FAILURE() {
        return holder.format("BuildStatus.FAILURE");
    }

    /**
     * Key {@code BuildStatus.FAILURE}: {@code Failure}.
     * 
     * @return
     *     {@code Failure}
     */
    public static Localizable _BuildStatus_FAILURE() {
        return new Localizable(holder, "BuildStatus.FAILURE");
    }

    /**
     * Key {@code SortingMethod.ALPHABETICAL}: {@code By feature name

     * (alphabetical)}.
     * 
     * @return
     *     {@code By feature name (alphabetical)}
     */
    public static String SortingMethod_ALPHABETICAL() {
        return holder.format("SortingMethod.ALPHABETICAL");
    }

    /**
     * Key {@code SortingMethod.ALPHABETICAL}: {@code By feature name

     * (alphabetical)}.
     * 
     * @return
     *     {@code By feature name (alphabetical)}
     */
    public static Localizable _SortingMethod_ALPHABETICAL() {
        return new Localizable(holder, "SortingMethod.ALPHABETICAL");
    }

    /**
     * Key {@code Configuration.notValidNumberRange}: {@code Provide positive

     * value}.
     * 
     * @return
     *     {@code Provide positive value}
     */
    public static String Configuration_notValidNumberRange() {
        return holder.format("Configuration.notValidNumberRange");
    }

    /**
     * Key {@code Configuration.notValidNumberRange}: {@code Provide positive

     * value}.
     * 
     * @return
     *     {@code Provide positive value}
     */
    public static Localizable _Configuration_notValidNumberRange() {
        return new Localizable(holder, "Configuration.notValidNumberRange");
    }

    /**
     * Key {@code Plugin.DisplayName}: {@code Cucumber reports}.
     * 
     * @return
     *     {@code Cucumber reports}
     */
    public static String Plugin_DisplayName() {
        return holder.format("Plugin.DisplayName");
    }

    /**
     * Key {@code Plugin.DisplayName}: {@code Cucumber reports}.
     * 
     * @return
     *     {@code Cucumber reports}
     */
    public static Localizable _Plugin_DisplayName() {
        return new Localizable(holder, "Plugin.DisplayName");
    }

    /**
     * Key {@code BuildStatus.unchanged}: {@code Left unchanged}.
     * 
     * @return
     *     {@code Left unchanged}
     */
    public static String BuildStatus_unchanged() {
        return holder.format("BuildStatus.unchanged");
    }

    /**
     * Key {@code BuildStatus.unchanged}: {@code Left unchanged}.
     * 
     * @return
     *     {@code Left unchanged}
     */
    public static Localizable _BuildStatus_unchanged() {
        return new Localizable(holder, "BuildStatus.unchanged");
    }

}
